==> haskell-fgl-5.5.3.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fgl
version: 5.5.3.0
id: fgl-5.5.3.0-KO9F4uETTjy3vgLQ22ev7I
key: fgl-5.5.3.0-KO9F4uETTjy3vgLQ22ev7I
license: BSD3
maintainer: Ivan.Miljenovic@gmail.com
synopsis: Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.
    .
    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.
category: Data Structures, Graphs
author: Martin Erwig, Ivan Lazar Miljenovic
exposed: True
exposed-modules:
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Monad Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Tree Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules: Paths_fgl
abi: a0b9d2419575a3f7bbeaf8416de0fd6a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fgl-5.5.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/fgl-5.5.3.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/fgl-5.5.3.0
hs-libraries: HSfgl-5.5.3.0-KO9F4uETTjy3vgLQ22ev7I
depends:
    array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html: /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-5.5.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fgl
version: 5.5.3.1
id: fgl-5.5.3.1-2Q40BhgK4kY4AvjBEglJMk
key: fgl-5.5.3.1-2Q40BhgK4kY4AvjBEglJMk
license: BSD3
maintainer: Ivan.Miljenovic@gmail.com
synopsis: Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.
    .
    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.
category: Data Structures, Graphs
author: Martin Erwig, Ivan Lazar Miljenovic
exposed: True
exposed-modules:
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Monad Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Tree Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules: Paths_fgl
abi: 45b5a3b8a749662a2a9f6b465fccea88
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fgl-5.5.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/fgl-5.5.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/fgl-5.5.3.1
hs-libraries: HSfgl-5.5.3.1-2Q40BhgK4kY4AvjBEglJMk
depends:
    array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html: /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
